# beamgis


[![image](https://img.shields.io/pypi/v/beamgis.svg)](https://pypi.python.org/pypi/beamgis)
[![image](https://img.shields.io/conda/vn/conda-forge/beamgis.svg)](https://anaconda.org/conda-forge/beamgis)


**A python package for geospatial analysis and mapping**


-   Free software: MIT License
-   Documentation: https://eafriyie28.github.io/beamgis
    

## Features

-   TODO
